## ------------------------------------------------------------------------
library("vembedr")
library("htmltools")

## ------------------------------------------------------------------------
embed_channel9(
  id = c("Events", "useR-international-R-User-conference", "useR2016", "Forty-years-of-S")
)

## ------------------------------------------------------------------------
embed_user2016(id = "Literate-Programming")

## ------------------------------------------------------------------------
embed_youtube(id = "q2nNzNo_Xps")

## ------------------------------------------------------------------------
div(align = "center", embed_youtube(id = "Qpoqzt2EHaA"))

## ------------------------------------------------------------------------
embed_vimeo(id = "48699174")

## ------------------------------------------------------------------------
embed_youtube(id = "8SGif63VW6E", query = list(start = 252))

## ----eval=FALSE----------------------------------------------------------
#  embed_vimeo(id = "98892825", fragment = "t=60")

## ----eval=FALSE----------------------------------------------------------
#  embed_youtube(id = "8SGif63VW6E") %>% use_start_time("4m12s")

## ----eval=FALSE----------------------------------------------------------
#  embed_vimeo(id = "98892825") %>% use_start_time("60")

## ------------------------------------------------------------------------
embed_user2016(id = "Day-3-Siepr-130-Ligtning-Talks-100-PM-140-PM") %>% 
  use_start_time("21m45s")

## ------------------------------------------------------------------------
rickroll_youtube()

## ------------------------------------------------------------------------
rickroll_vimeo()

## ----eval=FALSE----------------------------------------------------------
#  embed_youtube() %>% use_rickroll()

